package db

import (
	"context"
	"testing"

	"git.nochill.in/nochill/naice_pos/util"
	"github.com/google/uuid"
	"github.com/stretchr/testify/require"
)

var merchantID = uuid.MustParse("7e525a4b-4208-4f05-99a1-a75df475dd9b")

func createRandomProductCategory(t *testing.T) ProductCategory {
	arg := CreateProductCategoryParams{
		MerchantID: merchantID,
		Name:       util.RandomString(6),
	}

	productCategory, err := testQueries.CreateProductCategory(context.Background(), arg)
	require.NoError(t, err)
	require.Equal(t, productCategory.Name, arg.Name)

	return productCategory
}

func TestCreateProductCategory(t *testing.T) {
	createRandomProductCategory(t)
}

func TestListProductCategories(t *testing.T) {
	tries := 5
	for i := 0; i < tries; i++ {
		createRandomProductCategory(t)
	}

	arg := ListProductCategoriesByMerchantIDParams{
		MerchantID: merchantID,
		Limit:      5,
		Offset:     0,
	}

	listProductCategories, err := testQueries.ListProductCategoriesByMerchantID(context.Background(), arg)
	require.NoError(t, err)

	for _, productCategory := range listProductCategories {
		require.NotEmpty(t, productCategory)
		require.Equal(t, merchantID, productCategory.MerchantID)
	}
}

func TestUpdateProductCategory(t *testing.T) {
	productCategory := createRandomProductCategory(t)

	arg := UpdateProductCategoryParams{
		Name: util.RandomString(5),
		ID:   productCategory.ID,
	}

	updatedProductCategory, err := testQueries.UpdateProductCategory(context.Background(), arg)
	require.NoError(t, err)

	require.NotEqual(t, updatedProductCategory.Name, productCategory.Name)
	require.Equal(t, arg.Name, updatedProductCategory.Name)
}

func TestDeleteProductCategory(t *testing.T) {
	productCategory := createRandomProductCategory(t)

	err := testQueries.DeleteProductCategory(context.Background(), productCategory.ID)
	require.NoError(t, err)
}
